==> western-world-3.0.549.tgz: package/src/defs/bird/bird.js <==
const style = require('!!css-loader!sass-loader!./bird.scss').default;

export const bird = `
<symbol id="bird" viewBox="0 0 8192 8192">
	<style type="text/css">
		.bird_st0{fill: #FFFFFF;}
		.bird_st1{fill: var(--bird-color, #FFFFFF);}
		${style}
	</style>
	<defs>
	<mask id="mask-eye">
		<circle id="mask-eye-circle" fill="white" class="bird_st0" cx="4556.5" cy="3110.4" r="790.1"/>
	</mask>
	</defs>
	<g class="bird">
		<path id="body" class="bird_st1" d="M6157.1,4060.6c112.2,0,827.4,16.6,847.1-16.8c19.7-33.3,131.9-1064.1-973.1-1750.7s-2341.9-845.8-3096.8,395.6 S2989.8,5424,1888.3,6175c-133.4,90.9-108,177.5,242.5,118.2c215.2-36.4,324.4-142.5,327.4-90.9c3,51.5-244.3,373.7-751.8,609.3 c-169.8,78.8-78.8,157.6,109.1,154.6c188-3,2605.6,0,2846.7,0c241,0,654.8-66.7,904.9-489.6c250.1-422.9,348.8-1287,395.6-2191.8 C5976.4,4021.1,6157.1,4060.6,6157.1,4060.6z"/>
		<path id="leg_1" class="bird_st1" d="M3310.1,6775.2c0,0,479,618.4,509.3,648.8s78.8,51.5,175.8,36.4s81.9-84.9,15.2-130.4S3583,6775.2,3583,6775.2 H3310.1z"/>
		<path id="leg_2" class="bird_st1" d="M3740.6,6775.2c0,0,442.6,636.6,512.3,670c69.7,33.3,172.8,27.3,285,0s18.2-121.3-78.8-124.3 c-97-3-139.5-12.1-203.1-94s-288-451.7-288-451.7H3740.6z"/>
		<path id="feather" class="bird_st1" d="M4838.1,1976.3c0,0-615.4-309.2-760.9-757.9s-27.3-560.8,87.9-560.8c135.7,0-14.4,444.1,224.3,736.7 c95.8,117.4,219.8,300.1,583.6,442.6L4838.1,1976.3z"/>
		<g id="eye">
			<circle class="bird_st0" cx="4556.5" cy="3110.4" r="790.1"/>
			<ellipse id="pupil" mask="url(#mask-eye)" cx="4595.2" cy="3094.5" rx="490" ry="480.9"/>
		</g>
	</g>
</symbol>
`;

==> western-world-3.0.629.tgz: package/src/defs/bird/bird.js <==
const style = require('!!css-loader!sass-loader!./bird.scss').default;

export const bird = `
<symbol id="bird" viewBox="0 0 8192 8192">
	<style type="text/css">
		.bird_st0{fill: #FFFFFF;}
		.bird_st1{fill: var(--bird-color, #201D27);}
		${style}
	</style>
	<defs>
	<mask id="mask-eye">
		<circle id="mask-eye-circle" fill="white" class="bird_st0" cx="4556.5" cy="3110.4" r="790.1"/>
	</mask>
	</defs>
	<g class="bird">
		<path id="body" class="bird_st1" d="M6157.1,4060.6c112.2,0,827.4,16.6,847.1-16.8c19.7-33.3,131.9-1064.1-973.1-1750.7s-2341.9-845.8-3096.8,395.6 S2989.8,5424,1888.3,6175c-133.4,90.9-108,177.5,242.5,118.2c215.2-36.4,324.4-142.5,327.4-90.9c3,51.5-244.3,373.7-751.8,609.3 c-169.8,78.8-78.8,157.6,109.1,154.6c188-3,2605.6,0,2846.7,0c241,0,654.8-66.7,904.9-489.6c250.1-422.9,348.8-1287,395.6-2191.8 C5976.4,4021.1,6157.1,4060.6,6157.1,4060.6z"/>
		<path id="leg_1" class="bird_st1" d="M3310.1,6775.2c0,0,479,618.4,509.3,648.8s78.8,51.5,175.8,36.4s81.9-84.9,15.2-130.4S3583,6775.2,3583,6775.2 H3310.1z"/>
		<path id="leg_2" class="bird_st1" d="M3740.6,6775.2c0,0,442.6,636.6,512.3,670c69.7,33.3,172.8,27.3,285,0s18.2-121.3-78.8-124.3 c-97-3-139.5-12.1-203.1-94s-288-451.7-288-451.7H3740.6z"/>
		<path id="feather" class="bird_st1" d="M4838.1,1976.3c0,0-615.4-309.2-760.9-757.9s-27.3-560.8,87.9-560.8c135.7,0-14.4,444.1,224.3,736.7 c95.8,117.4,219.8,300.1,583.6,442.6L4838.1,1976.3z"/>
		<g id="eye">
			<circle class="bird_st0" cx="4556.5" cy="3110.4" r="790.1"/>
			<ellipse id="pupil" mask="url(#mask-eye)" cx="4595.2" cy="3094.5" rx="490" ry="480.9"/>
		</g>
	</g>
</symbol>
`;
